Crate bitcoinsecp256k1_field

Macros

fe_const
fe_const_inner
| Unpacks a constant into a overlapping | multi-limbed FE element. |
fe_storage_const
fe_storage_const_get
verify_bits

Structs

Fe
FeStorage

Constants

FE_ONE

Functions

fe_equal
| Compare two field elements. Requires | magnitude-1 inputs. |
fe_equal_var
| Same as fe_equal, but may be variable | time. |
fe_from_signed30
fe_mul_inner
fe_sqr_inner
fe_sqrt
| If a has a square root, it is computed | in r and 1 is returned. If a does not have | a square root, the root of its negation | is computed and 0 is returned. | | The input’s magnitude can be at most | 8. The output magnitude is 1 (but not | guaranteed to be normalized). The result | in r will always be a square itself. |
fe_to_signed30